#ifndef DAEMON_H
#define DAEMON_H

#include <QtCore>
#include "gps.h"
#include "glatitude.h"

class Daemon : public QObject {
    Q_OBJECT

public:
    Daemon(QObject *parent = 0);

private slots:
    void set();
    void set_config();
    void daemon_ok();
    void daemon_error();

private:
    QSettings *setting;
    GpsMaemo5 *gps;
    GoogleLatitude *glatitude;
};

#endif // DAEMON_H
